Struct EventLockingConditions

pub struct EventLockingConditions {
    pub locking_points: Vec<MaybePoint>,
    pub expiry: Option<u32>,
}
The locking points derived from the oracle’s announcement of a future event.

Fields

locking_points: Vec<MaybePoint>

An array of locking points which represent distinct outcomes. Each locking point should have its discrete log revealed by the oracle when and if that outcome occurs.

expiry: Option<u32>

The unix timestamp beyond which the oracle is considered to have gone AWOL. If set to None, the event has no expected expiry.

Implementations

Source

impl EventLockingConditions

pub fn is_valid_outcome(&self, outcome: &Outcome) -> bool

Returns true if the given outcome is a valid outcome to wager on for this event.

pub fn all_outcomes(&self) -> impl IntoIterator<Item = Outcome>

Returns an iterator over all possible outcomes in the event.