SigMap

Struct SigMap 

pub struct SigMap<T> {
    pub by_outcome: BTreeMap<Outcome, T>,
    pub by_win_condition: BTreeMap<WinCondition, T>,
}
Represents a mapping of different signature requirements to some arbitrary type T. This can be used to efficiently look up signatures, nonces, etc, for each outcome transaction, and for different WinConditions within each split transaction.

Fields

by_outcome: BTreeMap<Outcome, T>

Corresponds to the set of outcome transactions which the player needs to sign.

by_win_condition: BTreeMap<WinCondition, T>

Corresponds to the set of split transaction spending conditions which the player needs to sign.

Implementations

Source

impl<T> SigMap<T>

pub fn map<V, F1, F2>( self, map_outcomes: F1, map_win_conditions: F2, ) -> SigMap<V>
where F1: Fn(Outcome, T) -> V, F2: Fn(WinCondition, T) -> V,

Map each outcome and win condition to values of a specific type using distinct map functions.

pub fn map_values<V, F>(self, map_fn: F) -> SigMap<V>
where F: FnMut(T) -> V,

Map each outcome and win condition to values of a specific type.

pub fn by_ref(&self) -> SigMap<&T>

Return a SigMap which contains references to the values held by this SigMap.

pub fn is_mirror<V>(&self, other: &SigMap<V>) -> bool

Returns true if the given sigmap mirrors the keys of this sigmap exactly. This means both sigmaps have entries for all the same outcomes and win conditions, without any extra leftover entries.