pub struct SigMap<T> {
pub by_outcome: BTreeMap<Outcome, T>,
pub by_win_condition: BTreeMap<WinCondition, T>,
}Expand description
Represents a mapping of different signature requirements to some arbitrary type T.
This can be used to efficiently look up signatures, nonces, etc, for each
outcome transaction, and for different WinConditions within each split transaction.
Fields
by_outcome: BTreeMap<Outcome, T>Corresponds to the set of outcome transactions which the player needs to sign.
by_win_condition: BTreeMap<WinCondition, T>Corresponds to the set of split transaction spending conditions which the player needs to sign.
Implementations
Sourceimpl<T> SigMap<T>
impl<T> SigMap<T>
Sourcepub fn map<V, F1, F2>(
self,
map_outcomes: F1,
map_win_conditions: F2,
) -> SigMap<V>
pub fn map<V, F1, F2>( self, map_outcomes: F1, map_win_conditions: F2, ) -> SigMap<V>
Map each outcome and win condition to values of a specific type using distinct map functions.
Sourcepub fn map_values<V, F>(self, map_fn: F) -> SigMap<V>where
F: FnMut(T) -> V,
pub fn map_values<V, F>(self, map_fn: F) -> SigMap<V>where
F: FnMut(T) -> V,
Map each outcome and win condition to values of a specific type.